#
# spec file for package python-prometheus_client
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-prometheus_client
Version:        0.7.1
Release:        2.24
Summary:        Python client for the Prometheus monitoring system
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/prometheus/client_python
Source:         https://github.com/prometheus/client_python/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-futures
BuildRequires:  python-rpm-macros
Suggests:       python-twisted
Provides:       python-prometheus-client = %{version}-%{release}
Obsoletes:      python-prometheus-client < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
The official Python 2 and 3 client for Prometheus.

%prep
%setup -q -n client_python-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# some tests are currently broken in ppc64le 
# see https://bugzilla.suse.com/show_bug.cgi?id=1164604
%pytest -k "not TestProcessCollector"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu Feb 27 2020 stefano.torresi@suse.com
- Temporarily skip some tests failing on ppc64le due to upstream issues
  See bsc#1164604
* Mon Feb 17 2020 stefano.torresi@suse.com
- Add Provides and Obsoletes fields to correctly supersede SUSE:SLE-15-SP2:GA/python-prometheus-client
* Mon Jul 29 2019 abelarbi@suse.de
- Require python-futures instead of python2-futures for building for both sle12 and sle15
* Tue Jul 23 2019 tchvatal@suse.com
- Update to 0.7.1:
  * [BUGFIX] multiprocess: don't crash on missing gauge_live/sum files (#424)
  * [BUGFIX] correctly bind method on Python 2.x (#403)
* Thu Jun 20 2019 mcepl@suse.com
- Remove forgotten v0.6.0.tar.gz tarball.
* Wed Jun 19 2019 pgajdos@suse.com
- version update to 0.7.0
  * Multiprocess exposition speed boost (#421)
  * optimize openmetrics text parsing (~4x perf) (#402)
  * Add python3.7 support (#418)
  * Change exemplar length limit to be only for label names+values (#397)
  * Disable gcCollector for pypy (#380)
* Thu May 23 2019 mcalabkova@suse.com
- update to version 0.6.0
  * Better exceptions on exposition failure
  * Fix deadlock in gcCollector, metrics are now different
  * Fix thread leak in Python 3.7
  * parser: ensure samples are of type Sample
  0.5.0
  * Be more resilient to certain file corruptions
  * Permit subclassing of MetricsHandler
  * Updates based on latest OpenMetrics draft spec discussions
  * In multiprocess mode, ensure that metrics initialise to the
    correct file
  * Avoid re-entrant calls to GC collector's callback
  0.4.?
  * Disable GCCollector in multiprocess mode to prevent a deadlock
  * Fix OpenMetrics http negotiation handling
  * Counter time series will now always be exposed with _total, and
    counter metrics will have a _total suffix stripped. This is as
    the internal data model is now OpenMetrics, rather than
    Prometheus Text Format
  * Samples now use a namedtuple
  * Add OpenMetrics exposition and parser
  * Add Info, Stateset, Enum, GaugeHistogram support for OpenMetrics
  * Add timestamp support for Prometheus text format exposition
  * Add garbage collection metrics
  * If reading multiprocess file, open it readonly.
  * Fix bug in WSGI app code.
  * Write to multiprocess files directly
  0.3.?
  * Fix handing of escaping in parser
  * Fix concurrency issues with timers
  * 4.5x speedup in parser
  * Performance improvements for multiproc mode
  * Fix FD leak in multiproc mode
- Taking tarball from git because of the tests
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Fri May  4 2018 tbechtold@suse.com
- Initial packaging (version 0.2.0)
